@@ -4,5 +4,5 @@ from .loggers import *
 from .hooks import *
 from .get_trainer import get_trainer
 from .ds_wrappers import *
-from .neptune_project import download_model, get_neptune_experiment, get_token, get_neptune_project
+from .neptune_project import download_experiment, get_neptune_experiment, get_token, get_neptune_project
 
